Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1708)

Unified Diff: content/public/browser/browser_context.h

Issue 2398783002: Rename a bunch of Mojo Application stuff to reference Services. (Closed)
Patch Set: . Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/gpu/gpu_service_factory.cc ('k') | content/public/browser/browser_main_parts.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/browser/browser_context.h
diff --git a/content/public/browser/browser_context.h b/content/public/browser/browser_context.h
index 15be1d2ff416e7e673bb13560826d768fddfc6e0..aaa5e23e9f706b7d743179f3e5ec7c42fdc2a4a2 100644
--- a/content/public/browser/browser_context.h
+++ b/content/public/browser/browser_context.h
@@ -54,10 +54,10 @@ class BrowserPluginGuestManager;
class DownloadManager;
class DownloadManagerDelegate;
class IndexedDBContext;
-class MojoShellConnection;
class PermissionManager;
class PushMessagingService;
class ResourceContext;
+class ServiceManagerConnection;
class SiteInstance;
class StoragePartition;
class SSLHostStateDelegate;
@@ -147,27 +147,27 @@ class CONTENT_EXPORT BrowserContext : public base::SupportsUserData {
static void SetDownloadManagerForTesting(BrowserContext* browser_context,
DownloadManager* download_manager);
// Makes mojo aware of this BrowserContext, and assigns a user ID number to
// it. Should be called for each BrowserContext created.
static void Initialize(BrowserContext* browser_context,
const base::FilePath& path);
// Returns a Shell User ID associated with this BrowserContext. This ID is not
// persistent across runs. See
// services/shell/public/interfaces/connector.mojom. By default, this user id
// is randomly generated when Initialize() is called.
- static const std::string& GetShellUserIdFor(BrowserContext* browser_context);
+ static const std::string& GetServiceUserIdFor(
+ BrowserContext* browser_context);
// Returns the BrowserContext associated with |user_id|, or nullptr if no
// BrowserContext exists for that |user_id|.
- static BrowserContext* GetBrowserContextForShellUserId(
+ static BrowserContext* GetBrowserContextForServiceUserId(
const std::string& user_id);
// Returns a Connector associated with this BrowserContext, which can be used
// to connect to service instances bound as this user.
- static shell::Connector* GetShellConnectorFor(
- BrowserContext* browser_context);
- static MojoShellConnection* GetMojoShellConnectionFor(
+ static shell::Connector* GetConnectorFor(BrowserContext* browser_context);
+ static ServiceManagerConnection* GetServiceManagerConnectionFor(
BrowserContext* browser_context);
~BrowserContext() override;
« no previous file with comments | « content/gpu/gpu_service_factory.cc ('k') | content/public/browser/browser_main_parts.h » ('j') | no next file with comments »
@@ -147,27 +147,27 @@ class CONTENT_EXPORT BrowserContext : public base::SupportsUserData {
static void SetDownloadManagerForTesting(BrowserContext* browser_context,
DownloadManager* download_manager);
- // Makes mojo aware of this BrowserContext, and assigns a user ID number to
- // it. Should be called for each BrowserContext created.
+ // Makes the Service Manager aware of this BrowserContext, and assigns a user
+ // ID number to it. Should be called for each BrowserContext created.
static void Initialize(BrowserContext* browser_context,
const base::FilePath& path);
@@ -147,27 +147,27 @@ class CONTENT_EXPORT BrowserContext : public base::SupportsUserData {
static void Initialize(BrowserContext* browser_context,
const base::FilePath& path);
- // Returns a Shell User ID associated with this BrowserContext. This ID is not
- // persistent across runs. See
+ // Returns a Service User ID associated with this BrowserContext. This ID is
+ // not persistent across runs. See
// services/shell/public/interfaces/connector.mojom. By default, this user id
// is randomly generated when Initialize() is called.

Powered by Google App Engine
This is Rietveld 408576698